salabim
=======
The discrete event simulation package salabim follows the methodology of
activate/hold/passivate as demonstrated first in Simula.
The basic structure is very similar to SimPy2, but with some important
extras: statistical distributions, queues, automatic monitoring and ...
animation.
